%Author: Serge Shikher, Suffolk University.
%This program accompanies Shikher, S. "Capital, technology, and specialization in the neoclassical model".

%This function solves the baseline model

function res=cf2(name,descrip,data,base0)

%Getting variables from the data structure
N=data.N;
J=data.J;
alpha=data.alpha;
beta=data.beta;
etaM=data.etaM;
etaI=1;
rw=data.rw;
w=data.w;
Q=data.Q;
tradedata=data.trade;
EX=data.EX;
IM=data.IM;
d=data.d;
delta=data.delta;
theta=base0.theta;
n_US=19;

%Matching output, spending, and trade
X=Q-EX+IM; %EX and IM are exports and imports to/from other countries in the sample (not total exports/imports)

%Setting up initial values
c0=base0.c;
T0=base0.T;

%Running simulation
fprintf('-----------------------------------------------------------------------\n');
fprintf('>>> Name: %s. Description: %s.\n',name,descrip);
fprintf('-----------------------------------------------------------------------\n');
fprintf('>>> Starting simulation.\n');
fprintf('-----------------------------------------------------------------------\n');
markstart=now;
    
[c,p,rho,pi,T,r,exitflag,output]=simulatebase(alpha,beta,etaM,etaI,theta,w,d,X,Q,rw,c0,T0,N,J);
 
markend=now;

%Running diagnostics
testreal=0;
if isreal(c) & isreal(T)
    testreal=1;
end;

if testreal==0
    fprintf('>>> The optimization has successfully finished, but results contain complex numbers.\n');
elseif exitflag<=0
    fprintf('>>> The simulation did not complete successfully.\n');
else
    fprintf('>>> The simulation has completed successfully.\n');
end;
    
fprintf('>>> The simulation finished running. It took %s.\n',datestr(markend-markstart,13));

%Packaging results
res.name=name;
res.descrip=descrip;
res.theta=theta;
res.c=c;
res.p=p;
res.pi=pi;
res.X=X;
res.T=T;
res.r=r;
res.ef=exitflag;
