%Author: Serge Shikher, Suffolk University.
%This program accompanies Shikher, S. "Capital, technology, and specialization in the neoclassical model".

function [c,p,rho,pi,T,r,exitflag,output]=simulatebase(alpha,beta,eta,etaI,theta,w,d,X,Q,rw,c0,T0,N,J)

%setting up the starting point
cij0=reshape(c0,[N*J,1]);
Tij0=reshape(T0,[N*J,1]);
Xij0=zeros(N*J*2,1);
Xij0(1:N*J,1)=cij0;
Xij0(N*J+1:N*J*2)=Tij0.*100;

%setting up derived variables
B=repmat((-(ones(J,1)-alpha-beta)./theta),[1,J]).*eta;

%solving the model
options=optimset('Display','iter','TolFun',1e-9,'TolX',1e-9,'MaxFunEvals',10000000,'MaxIter',1500,'LargeScale','off','NonlEqnAlgorithm','dogleg');
[Xij,fval,exitflag,output]=fsolve(@eqbase,Xij0,options,alpha,beta,etaI,theta,B,w,d,X,Q,rw,N,J);

%transforming results into 2-dimentional matrices
c=reshape(Xij(1:N*J,1),[N,J]); %transforming cost data into a 2-dimentional NxJ matrix
T=reshape(Xij(N*J+1:N*J*2,1),[N,J])./100; %transforming technology parameter data into a 2-dimentional NxJ matrix

%calculating prices, returns, and trade
D=repmat(shiftdim(T,-1),[N,1,1]).*(d.^(-theta));
p=(squeeze(sum(D.*repmat(shiftdim(c.^(-theta),-1),[N,1,1]),2))) .^ (-1/theta);
rho=zeros(N,J);
for i=1:N
    for j=1:J
        rho(i,j)=prod(p(i,:).^eta(j,:),2);
    end;
end;
r=repmat(rw,[N,1]);
pi=D.*(repmat(shiftdim(c.^(-theta),-1),[N,1,1])./repmat(reshape(p.^(-theta),[N,1,J]),[1,N,1]));

