%Author: Serge Shikher, Suffolk University.
%This program accompanies Shikher, S. "Capital, technology, and specialization in the neoclassical model".

%Xij is the vector of endogenous variables cij, Lij, wi, Kij, and ri

function out=eqsystem(Xij,alpha,beta,phi,theta,B,CL,CK,D,Ln,Kn,VAnO,N,J)

c=reshape(Xij(1:N*J,1),[N,J]); %transforming cost data into a 2-dimentional NxJ matrix
L=reshape(Xij(N*J+1:N*J+N*(J-1),1),N,J-1); %transforming employment data into a 2-dimentional Nx(J-1) matrix
L=[L,Ln-sum(L,2)]; %adding the last industry to the labor matrix using the market clearing condition; L is now NxJ
w=repmat(Xij(N*J+N*(J-1)+1:N*J*2,1),[1,J]); %w is NxJ where all industries have the same wage
K=reshape(Xij(N*J*2+1:N*J*2+N*(J-1),1),N,J-1); %transforming capital stock data into a 2-dimentional Nx(J-1) matrix
r=repmat(Xij(N*J*2+N*(J-1)+1:N*J*3,1),[1,J]); %r is NxJ where all industries have the same rate of return

%calculating cost equation
coutmat=c-(w.^repmat(beta',[N,1])).*(r.^repmat(alpha',[N,1])).*...
    squeeze(prod(repmat(sum(D.*repmat(shiftdim(c.^(-theta),-1),[N,1,1]),2),[1,J,1]).^repmat(shiftdim(B,-1),[N,1,1]),3));

%calculating prices and trade
p=(squeeze(sum(D.*repmat(shiftdim(c.^(-theta),-1),[N,1,1]),2))) .^ (-1/theta);
pi=D.*(repmat(shiftdim(c.^(-theta),-1),[N,1,1])./repmat(reshape(p.^(-theta),[N,1,J]),[1,N,1]));

%calculating current country capital stocks
K=[K,Kn-sum(K,2)]; %adding the last industry to the capital stock matrix using the market clearing condition; K is now NxJ

%calculating employment equation
Znj=squeeze(sum(repmat(shiftdim(CL,-1),[N,1,1]).*repmat(w.*L,[1,1,J]),2)); %Znj is NxJ
VAn=sum(repmat(((alpha+beta)./beta)',[N,1]).*w.*L,2)+VAnO;
Loutmat=log(w.*L)-...
    log(repmat(beta',[N,1]).*squeeze(sum(pi.*repmat(reshape(Znj+repmat(VAn,[1,J]).*phi,[N,1,J]),[1,N,1]),1)));

%calculating capital equation
Znj=squeeze(sum(repmat(shiftdim(CK,-1),[N,1,1]).*repmat(r.*K,[1,1,J]),2)); %Znj is NxJ
VAn=sum(repmat(((alpha+beta)./alpha)',[N,1]).*r.*K,2)+VAnO;
Koutmat=log(r.*K)-...
    log(repmat(alpha',[N,1]).*squeeze(sum(pi.*repmat(reshape(Znj+repmat(VAn,[1,J]).*phi,[N,1,J]),[1,N,1]),1)));

%packaging output vector
out=zeros(N*J*3,1);
out(1:N*J,1)=reshape(coutmat,[N*J,1]);
out(N*J+1:N*J*2,1)=reshape(Loutmat,[N*J,1]);
out(N*J*2+1:N*J*3)=reshape(Koutmat,[N*J,1]);
