%Author: Serge Shikher, Suffolk University.
%This program accompanies Shikher, S. "Capital, technology, and specialization in the neoclassical model".

function [c,p,rho,pi,L,w,K,r,exitflag,output]=simulatesystem(alpha,beta,eta,phi,theta,T,d,Ln,Kn,VAnO,c0,L0,w0,K0,r0,N,J)

%setting up the starting point
cij0=reshape(c0,[N*J,1]);
Lij0=reshape(L0(:,1:J-1),[N*(J-1),1]);
Kij0=reshape(K0(:,1:J-1),[N*(J-1),1]);
Xij0=zeros(N*J*2,1);
Xij0(1:N*J,1)=cij0;
Xij0(N*J+1:N*J+N*(J-1),1)=Lij0;
Xij0(N*J+N*(J-1)+1:N*J*2,1)=w0;
Xij0(N*J*2+1:N*J*2+N*(J-1),1)=Kij0;
Xij0(N*J*2+N*(J-1)+1:N*J*3,1)=r0;

%setting up derived variables
B=repmat((-(ones(J,1)-alpha-beta)./theta),[1,J]).*eta;
CL=repmat((ones(J,1)-alpha-beta)./beta,[1,J]).*eta;
CK=repmat((ones(J,1)-alpha-beta)./alpha,[1,J]).*eta;
D=repmat(shiftdim(T,-1),[N,1,1]).*(d.^(-theta));

%solving the model
disp('*** Solving the system...');
options=optimset('Display','iter','TolFun',1e-9,'TolX',1e-9,'MaxFunEvals',10000000,'MaxIter',1500,'LargeScale','off','NonlEqnAlgorithm','dogleg');
[Xij,fval,exitflag,output]=fsolve(@eqsystem,Xij0,options,alpha,beta,phi,theta,B,CL,CK,D,Ln,Kn,VAnO,N,J);
disp('*** Done');

%transforming results into 2-dimentional matrices
cij=Xij(1:N*J,1); %cij is N*Jx1
Lij=Xij(N*J+1:N*J+N*(J-1),1); %Lij is N*(J-1)x1 because the last industry is calculated from market clearing
w=Xij(N*J+N*(J-1)+1:N*J*2,1); %w is Nx1
Kij=Xij(N*J*2+1:N*J*2+N*(J-1),1); %Kij is N*(J-1)x1 because the last industry is calculated from market clearing
r=Xij(N*J*2+N*(J-1)+1:N*J*3,1); %r is Nx1
c=reshape(cij(:,1),[N,J]); %transforming cij into a 2-dimentional NxJ matrix
L=reshape(Lij(:,1),N,J-1); %transforming Lij into a 2-dimentional Nx(J-1) matrix
L=[L,Ln-sum(L,2)]; %adding the last industry to the labor matrix using the market clearing condition; L is now NxJ
p=(squeeze(sum(D.*repmat(shiftdim(c.^(-theta),-1),[N,1,1]),2))) .^ (-1/theta);
VAn=sum(repmat(((alpha+beta)./beta)',[N,1]).*repmat(w,[1,J]).*L,2)+VAnO;
K=reshape(Kij(:,1),N,J-1); %transforming Kij into a 2-dimentional Nx(J-1) matrix
K=[K,Kn-sum(K,2)]; %adding the last industry to the capital matrix using the market clearing condition; K is now NxJ

%calculating prices and trade in equilibrium
rho=zeros(N,J);
for i=1:N
    for j=1:J
        rho(i,j)=prod(p(i,:).^eta(j,:),2);
    end;
end;
pi=D.*(repmat(shiftdim(c.^(-theta),-1),[N,1,1])./repmat(reshape(p.^(-theta),[N,1,J]),[1,N,1]));
